@@ -12,6 +12,12 @@ describe 'basic swift' do
       include ::openstack_integration::mysql
       include ::openstack_integration::keystone
 
+      exec { 'setenforce 0':
+        path   => '/bin:/sbin:/usr/bin:/usr/sbin',
+        onlyif => 'which setenforce && getenforce | grep Enforcing',
+        before => Class['::swift'],
+      }
+
       package { 'curl': ensure => present }
 
       class { '::memcached':
@@ -57,7 +63,7 @@ describe 'basic swift' do
         account_autocreate => true,
       }
       class { '::swift::proxy::authtoken':
-        admin_password => 'a_big_secret',
+        password => 'a_big_secret',
       }
       class { '::swift::keystone::dispersion': } -> class { '::swift::dispersion': }
       class {'::swift::objectexpirer':
@@ -69,7 +75,6 @@ describe 'basic swift' do
       }
       EOS
 
-
       # Need to be run 2 times because we have an exported when creating the ring.
       apply_manifest(pp, :catch_failures => false)
       apply_manifest(pp, :catch_failures => true)
@@ -93,6 +98,12 @@ describe 'basic swift' do
       include ::openstack_integration::mysql
       include ::openstack_integration::keystone
 
+      exec { 'setenforce 0':
+        path   => '/bin:/sbin:/usr/bin:/usr/sbin',
+        onlyif => 'which setenforce && getenforce | grep Enforcing',
+        before => Class['::swift'],
+      }
+
       package { 'curl': ensure => present }
 
       class { '::memcached':
